//importing modules select, json, geoPath, geoEquirectangular functions from d3
import { select, json, geoPath,zoom,event, geoEquirectangular } from 'd3';
//importing feature method from TopoJSON which will create the GeoJSON objects
import { feature } from 'topojson';

//creating a svg constant
//accessing DOM element using select()
const svg = select('svg');

//creating projection and pathGenerator constants
//using 'geoEquirectangular()' function as a geo-projection to view the world map 
const projection = geoEquirectangular();
//projecting the world map using geoPath().projection
const pathGenerator = geoPath().projection(projection);

//adding path element to the created SVG
//defining an attribute class as 'earth'
//considering pathGenerator type as Sphere
svg.append('path')
    .attr('class', 'earth')
    .attr('d', pathGenerator({type: 'Sphere'}));
//Allowing zoom operation to be performed on map
svg.call(zoom().on('zoom', () => {
  	svg.attr('transform', event.transform)
}));



//.json file which containing the data required to visualise world map
json('https://cdn.jsdelivr.net/npm/world-atlas@2/countries-110m.json')
  .then(data => {
    const countries = feature(data, data.objects.countries); //creating countries constant
//'selectAll()' function is used to select all the element that matches the specified selector string
    svg.selectAll('path').data(countries.features)
//enter() creates the initial join of data to elements
//defining a class 'countries'
      .enter().append('path')
        .attr('class', 'countries')
        .attr('d', pathGenerator);
  });